@@ -3,23 +3,23 @@ sub.abbr <- function(x) {
 #  Sys.setlocale("LC_ALL","C")
     iconv(x, "latin1", "")
     x <- sub('\ ag[.]', ' agg.', x, perl=TRUE, useBytes=TRUE)
-    x <- sub('\ subsp[.]', ' ssp.', x, perl=TRUE, useBytes=TRUE)
+    x <- sub('\ ssp[.]', ' subsp.', x, perl=TRUE, useBytes=TRUE)
     x <- sub('\ v[.]\ ', ' var.', x, perl=TRUE, useBytes=TRUE)
     x <- sub('\ s[.]l[.]', ' s. l.', x, perl=TRUE, useBytes=TRUE)
     x <- sub('\ s[.]str[.]', ' s. str.', x, perl=TRUE, useBytes=TRUE)
     x <- sub('\ s[.]\ str[.]', ' sensustricto', x, perl=TRUE, useBytes=TRUE)
     x <- sub('\ s[.]\ l[.]', ' sensulato', x, perl=TRUE, useBytes=TRUE)
-    x <- sub('\ s[.]\ ', ' ssp. ', x, fixed=TRUE, useBytes=TRUE)
+    x <- sub('\ s[.]\ ', ' subsp. ', x, fixed=TRUE, useBytes=TRUE)
     x <- sub('\ sensustricto', ' s. str.', x, perl=TRUE, useBytes=TRUE)
     x <- sub('\ sensulato', ' s. l.', x, perl=TRUE, useBytes=TRUE)
 #  Sys.setlocale(category='LC_CTYPE', locale=loc)
-    x
+   return(x)  
 }
 
 tax <- function(x, refl='Germansl 1.1', tv_home, syn = FALSE, tax = FALSE, concept = NULL, ...) {
   if(missing(tv_home)) tv_home <- tv.home(...)
   if(missing(refl)) refl <- tv.refl(...)
-  if(!is.null(concept))  tax=TRUE
+  if(!is.null(concept)) tax=TRUE
   dbf <- if(tax) 'tax.dbf' else 'species.dbf'
  if(file.access(paste(tv_home, 'Species', refl, dbf, sep='/'))) stop(paste('Taxonomic evaluation list (',dbf, ') of ', refl, 'not available')) else 
   species <- read.dbf(paste(tv_home, 'Species', refl, dbf, sep='/'))
@@ -43,10 +43,12 @@ tax <- function(x, refl='Germansl 1.1', tv_home, syn = FALSE, tax = FALSE, conce
   if(refl=='Germansl 1.1' && tax==FALSE) species <- species[,c(1,2,4,5,7,8)]
   if(x[1] != 'all') {
    if(is.numeric(x)) l <- species[match(x, species$SPECIES_NR),]
-   if(is.character(x) & nchar(x)[1]== 7) 
-        l <- species[species$LETTERCODE %in% x,]
-   if(is.character(x) & nchar(x)[1] > 7) 
-        l <- species[species$ABBREVIAT %in% x,] 
+   if(is.character(x)) {
+    x <- unique(unlist(strsplit(x, ".", fixed = TRUE)))
+    if(nchar(x[1]) == 7)  
+	l <- species[species$LETTERCODE %in% x,] else
+        l <- sapply(x, function(x) species[grep(x,species$ABBREVIAT),]) 
+        }
    if(syn == FALSE & !is.numeric(x)) l <- l[l$SYNONYM == FALSE,]
    l <- l[!is.na(l$ABBREVIAT),]
    if(length(l) == 0) stop('No species found!') 
@@ -55,3 +57,4 @@ tax <- function(x, refl='Germansl 1.1', tv_home, syn = FALSE, tax = FALSE, conce
 
 spc <- function(...) print('Function spc() is depreacated, please use function tax() instead')
 
+
